@@ -153,7 +153,7 @@ class TelegramChannelScraper(umbraSnscrpe.base.Scraper):
 		membersDiv = soup.find('div', class_ = 'tgme_page_extra')
 		if membersDiv.text.endswith(' members'):
 			kwargs['members'] = int(membersDiv.text[:-8].replace(' ', ''))
-		kwargs['photo'] = soup.find('img', class_ = 'tgme_page_photo_image').attrs['umbraSnscrpe']
+		kwargs['photo'] = soup.find('img', class_ = 'tgme_page_photo_image').attrs['src']
 
 		r, soup = self._initial_page()
 		if '/s/' not in r.url: # Redirect on channels without public posts
